@@ -34,6 +34,7 @@
 
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/accelmap.h>
+#include <gtkmm2ext/application.h>
 
 #include <pbd/error.h>
 #include <pbd/basename.h>
@@ -643,6 +644,11 @@ Please consider the possibilities, and perhaps (re)start JACK."));
 void
 ARDOUR_UI::startup ()
 {
+	Application* app = Application::instance();
+
+	app->ShouldQuit.connect (sigc::mem_fun (*this, &ARDOUR_UI::queue_finish));
+	app->ShouldLoad.connect (sigc::mem_fun (*this, &ARDOUR_UI::idle_load));
+
 	string name, path;
 	
 	new_session_dialog = new NewSessionDialog();
@@ -653,7 +659,9 @@ ARDOUR_UI::startup ()
 	if (audio_setup) {
 		new_session_dialog->engine_control.set_state (*audio_setup);
 	}
-	
+
+	app->ready ();
+
 	if (!get_session_parameters (backend_audio_is_running, ARDOUR_COMMAND_LINE::new_session)) {
 		return;
 	}
@@ -1157,8 +1165,8 @@ ARDOUR_UI::open_recent_session ()
 			return;
 		}
 		
-		Glib::ustring path = (*i)[recent_session_columns.fullpath];
-		Glib::ustring state = (*i)[recent_session_columns.visible_name];
+		std::string path = (*i)[recent_session_columns.fullpath];
+		std::string state = (*i)[recent_session_columns.visible_name];
 		
 		_session_is_new = false;
 		
@@ -2143,7 +2151,7 @@ ARDOUR_UI::fontconfig_dialog ()
 	   may not and it can take a while to build it. Warn them.
 	*/
 	
-	Glib::ustring fontconfig = Glib::build_filename (Glib::get_home_dir(), ".fontconfig");
+	std::string fontconfig = Glib::build_filename (Glib::get_home_dir(), ".fontconfig");
 	
 	if (!Glib::file_test (fontconfig, Glib::FILE_TEST_EXISTS|Glib::FILE_TEST_IS_DIR)) {
 		MessageDialog msg (*new_session_dialog,
@@ -2165,7 +2173,7 @@ ARDOUR_UI::fontconfig_dialog ()
 }
 
 void
-ARDOUR_UI::parse_cmdline_path (const Glib::ustring& cmdline_path, Glib::ustring& session_name, Glib::ustring& session_path, bool& existing_session)
+ARDOUR_UI::parse_cmdline_path (const std::string& cmdline_path, std::string& session_name, std::string& session_path, bool& existing_session)
 {
 	existing_session = false;
 
@@ -2184,7 +2192,7 @@ ARDOUR_UI::parse_cmdline_path (const Glib::ustring& cmdline_path, Glib::ustring&
 }
 
 int
-ARDOUR_UI::load_cmdline_session (const Glib::ustring& session_name, const Glib::ustring& session_path, bool& existing_session)
+ARDOUR_UI::load_cmdline_session (const std::string& session_name, const std::string& session_path, bool& existing_session)
 {
 	/* when this is called, the backend audio system must be running */
 
@@ -2200,7 +2208,7 @@ ARDOUR_UI::load_cmdline_session (const Glib::ustring& session_name, const Glib::
 	
 	if (Glib::file_test (session_path, Glib::FILE_TEST_IS_DIR)) {
 
-		Glib::ustring predicted_session_file;
+		std::string predicted_session_file;
                 
                 predicted_session_file = Glib::build_filename (session_path, session_name + Session::statefile_suffix());
 		
@@ -2230,9 +2238,9 @@ ARDOUR_UI::load_cmdline_session (const Glib::ustring& session_name, const Glib::
 }
 
 bool
-ARDOUR_UI::ask_about_loading_existing_session (const Glib::ustring& session_path)
+ARDOUR_UI::ask_about_loading_existing_session (const std::string& session_path)
 {
-	Glib::ustring str = string_compose (_("This session\n%1\nalready exists. Do you want to open it?"), session_path);
+	std::string str = string_compose (_("This session\n%1\nalready exists. Do you want to open it?"), session_path);
 	
 	MessageDialog msg (str,
 			   false,
@@ -2241,8 +2249,8 @@ ARDOUR_UI::ask_about_loading_existing_session (const Glib::ustring& session_path
 			   true);
 	
 	
-	msg.set_name (X_("CleanupDialog"));
-	msg.set_title (_("Cleanup Unused Sources"));
+        msg.set_name (X_("OpenExistingDialog"));
+        msg.set_title (_("Open Existing Session"));
 	msg.set_wmclass (X_("existing_session"), PROGRAM_NAME);
 	msg.set_position (Gtk::WIN_POS_MOUSE);
 	pop_back_splash ();
@@ -2256,7 +2264,7 @@ ARDOUR_UI::ask_about_loading_existing_session (const Glib::ustring& session_path
 }
 
 int
-ARDOUR_UI::build_session_from_nsd (const Glib::ustring& session_path, const Glib::ustring& session_name)
+ARDOUR_UI::build_session_from_nsd (const std::string& session_path, const std::string& session_name)
 {
 	
 	uint32_t cchns;
@@ -2344,9 +2352,10 @@ ARDOUR_UI::loading_message (const std::string& msg)
 }
 
 void
-ARDOUR_UI::idle_load (const Glib::ustring& path)
+ARDOUR_UI::idle_load (const std::string& path)
 {
 	if (session) {
+
 		if (Glib::file_test (path, Glib::FILE_TEST_IS_DIR)) {
 			/* /path/to/foo => /path/to/foo, foo */
 			load_session (path, basename_nosuffix (path));
@@ -2354,13 +2363,13 @@ ARDOUR_UI::idle_load (const Glib::ustring& path)
 			/* /path/to/foo/foo.ardour => /path/to/foo, foo */
 			load_session (Glib::path_get_dirname (path), basename_nosuffix (path));
 		}
+
 	} else {
 
 		ARDOUR_COMMAND_LINE::session_name = path;
 
 		if (new_session_dialog) {
 
-
 			/* make it break out of Dialog::run() and
 			   start again.
 			 */
@@ -2374,9 +2383,9 @@ bool
 ARDOUR_UI::get_session_parameters (bool backend_audio_is_running, bool should_be_new)
 {
 	bool existing_session = false;
-	Glib::ustring session_name;
-	Glib::ustring session_path;
-	Glib::ustring template_name;
+	std::string session_name;
+	std::string session_path;
+	std::string template_name;
 	int response;
 	
   begin:
@@ -2504,7 +2513,7 @@ ARDOUR_UI::get_session_parameters (bool backend_audio_is_running, bool should_be
 
 			}
 
-			template_name = Glib::ustring();			
+			template_name = std::string();			
 			switch (new_session_dialog->which_page()) {
 
 			case NewSessionDialog::OpenPage: 
@@ -2523,7 +2532,7 @@ ARDOUR_UI::get_session_parameters (bool backend_audio_is_running, bool should_be
 				
 				should_be_new = true;
 
-				if (session_name.find ('/') != Glib::ustring::npos) {
+				if (session_name.find ('/') != std::string::npos) {
 					MessageDialog msg (*new_session_dialog, _("To ensure compatibility with various systems\n"
 							 "session names may not contain a '/' character"));
 					msg.run ();
@@ -2531,7 +2540,7 @@ ARDOUR_UI::get_session_parameters (bool backend_audio_is_running, bool should_be
 					goto try_again;
 				}
 
-				if (session_name.find ('\\') != Glib::ustring::npos) {
+				if (session_name.find ('\\') != std::string::npos) {
 					MessageDialog msg (*new_session_dialog, _("To ensure compatibility with various systems\n"
 							 "session names may not contain a '\\' character"));
 					msg.run ();
@@ -2616,7 +2625,7 @@ ARDOUR_UI::close_session ()
 }
 
 int
-ARDOUR_UI::load_session (const Glib::ustring& path, const Glib::ustring& snap_name, Glib::ustring mix_template)
+ARDOUR_UI::load_session (const std::string& path, const std::string& snap_name, std::string mix_template)
 {
 	Session *new_session;
 	int unload_status;
@@ -2737,7 +2746,7 @@ ARDOUR_UI::load_session (const Glib::ustring& path, const Glib::ustring& snap_na
 }
 
 int
-ARDOUR_UI::build_session (const Glib::ustring& path, const Glib::ustring& snap_name, 
+ARDOUR_UI::build_session (const std::string& path, const std::string& snap_name, 
 			  uint32_t control_channels,
 			  uint32_t master_channels, 
 			  AutoConnectOption input_connect,
@@ -2907,8 +2916,8 @@ require some unused files to continue to exist."));
 		    add (visible_name);
 		    add (fullpath);
 	    }
-	    Gtk::TreeModelColumn<Glib::ustring> visible_name;
-	    Gtk::TreeModelColumn<Glib::ustring> fullpath;
+	    Gtk::TreeModelColumn<std::string> visible_name;
+	    Gtk::TreeModelColumn<std::string> fullpath;
 	};
 
 	
