@@ -120,7 +120,7 @@ AUPluginUI::AUPluginUI (boost::shared_ptr<PluginInsert> insert)
 		error << _("unknown type of editor-supplying plugin (note: no AudioUnit support in this version of ardour)") << endmsg;
 		throw failed_constructor ();
 	}
-
+	
 	/* stuff some stuff into the top of the window */
 
 	HBox* smaller_hbox = manage (new HBox);
@@ -171,8 +171,15 @@ AUPluginUI::AUPluginUI (boost::shared_ptr<PluginInsert> insert)
 	/* prefer cocoa, fall back to cocoa, but use carbon if its there */
 
 	if (test_cocoa_view_support()) {
-		create_cocoa_view ();
+	        cerr << insert->name() << " creating cocoa view\n";
+		if (create_cocoa_view () != 0) {
+			if (test_carbon_view_support()) {
+				cerr << insert->name() << " falling back to carbon view\n";
+				create_carbon_view ();
+			}
+		}
 	} else if (test_carbon_view_support()) {
+	        cerr << insert->name() << " creating carbon view\n";
 		create_carbon_view ();
 	} else {
 		create_cocoa_view ();
@@ -268,11 +275,11 @@ AUPluginUI::create_cocoa_view ()
 {
 	BOOL wasAbleToLoadCustomView = NO;
 	AudioUnitCocoaViewInfo* cocoaViewInfo = NULL;
-	UInt32               numberOfClasses = 0;
+	UInt32     numberOfClasses = 0;
 	UInt32     dataSize;
 	Boolean    isWritable;
-	NSString*	    factoryClassName = 0;
-	NSURL*	            CocoaViewBundlePath;
+	NSString*  factoryClassName = 0;
+	NSURL*     CocoaViewBundlePath = 0;
 
 	OSStatus result = AudioUnitGetPropertyInfo (*au->get_au(),
 						    kAudioUnitProperty_CocoaUI,
@@ -286,7 +293,9 @@ AUPluginUI::create_cocoa_view ()
 	// Does view have custom Cocoa UI?
 	
 	if ((result == noErr) && (numberOfClasses > 0) ) {
+		cerr << insert->name() << " has " << numberOfClasses << " cocoa UI classes\n";
 		cocoaViewInfo = (AudioUnitCocoaViewInfo *)malloc(dataSize);
+
 		if(AudioUnitGetProperty(*au->get_au(),
 					kAudioUnitProperty_CocoaUI,
 					kAudioUnitScope_Global,
@@ -298,6 +307,12 @@ AUPluginUI::create_cocoa_view ()
 			
 			// we only take the first view in this example.
 			factoryClassName	= (NSString *)cocoaViewInfo->mCocoaAUViewClass[0];
+			if (factoryClassName) {
+				cerr << insert->name() << " no factory name class name provided\n";
+			} else {
+				const char* fcn = [factoryClassName UTF8String];
+				cerr << insert->name() << " fetching cocoa UI via factory called " << fcn << '\n';
+			}
 
 		} else {
 
@@ -321,6 +336,7 @@ AUPluginUI::create_cocoa_view ()
 			Class factoryClass = [viewBundle classNamed:factoryClassName];
 			if (!factoryClass) {
 				error << _("AUPluginUI: error getting AU view's factory class from bundle") << endmsg;
+				cerr << _("AUPluginUI: error getting AU view's factory class from bundle") << endl;
 				return -1;
 			}
 			
@@ -523,7 +539,6 @@ int
 AUPluginUI::parent_cocoa_window ()
 {
 	NSWindow* win = get_nswindow ();
-	NSRect packFrame;
 
 	if (!win) {
 		return -1;
@@ -631,7 +646,7 @@ AUPluginUI::on_window_hide ()
 }
 
 bool
-AUPluginUI::on_window_show (const Glib::ustring& title)
+AUPluginUI::on_window_show (const string& title)
 {
 	/* this is idempotent so just call it every time we show the window */
 
