@@ -15,7 +15,7 @@
      along with this program; if not, write to the Free Software
      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-     $Id: canvas-waveview.c 5756 2009-10-08 14:40:09Z paul $
+     $Id: canvas-waveview.c 7475 2010-07-23 01:03:54Z paul $
 */
 
 #include <stdio.h>
@@ -1246,12 +1246,12 @@ gnome_canvas_waveview_render (GnomeCanvasItem *item,
 		max = waveview->cache->data[cache_index].max;
 		min = waveview->cache->data[cache_index].min;
 		
-		if (max >= 1.0) {
+		if (max >= 0.98853) { // -0.9dBFS
 			max = 1.0;
 			next_clip_max = 1;
 		}
 		
-		if (min <= -1.0) {
+		if (min <= -0.98853) { // ditto
 			min = -1.0;
 			next_clip_min = 1;
 		}
