@@ -3,9 +3,11 @@
 #include <fstream>
 #include <map>
 
+#include <boost/scoped_ptr.hpp>
 #include <glibmm.h>
 #include <gtkmm/messagedialog.h>
 #include <pbd/xml++.h>
+#include <pbd/epa.h>
 
 #ifdef __APPLE__
 #include <CoreAudio/CoreAudio.h>
@@ -400,6 +402,8 @@ EngineControl::build_command_line (vector<string>& cmd)
 		cmd.push_back ("-R");
 		cmd.push_back ("-P");
 		cmd.push_back (to_string ((uint32_t) floor (priority_spinner.get_value()), std::dec));
+	} else {
+		cmd.push_back ("-r"); /* override jackd's default --realtime */
 	}
 
 	if (unlock_memory_button.get_active()) {
@@ -558,6 +562,17 @@ EngineControl::build_command_line (vector<string>& cmd)
 bool
 EngineControl::engine_running ()
 {
+        EnvironmentalProtectionAgency* global_epa = EnvironmentalProtectionAgency::get_global_epa ();
+        boost::scoped_ptr<EnvironmentalProtectionAgency> current_epa;
+
+        /* revert all environment settings back to whatever they were when ardour started
+         */
+
+        if (global_epa) {
+                current_epa.reset (new EnvironmentalProtectionAgency(true)); /* will restore settings when we leave scope */
+                global_epa->restore ();
+        }
+	
 	jack_status_t status;
 	jack_client_t* c = jack_client_open ("ardourprobe", JackNoStartServer, &status);
 
@@ -580,7 +595,7 @@ EngineControl::setup_engine ()
 		return 1; // try again
 	}
 
-	Glib::ustring jackdrc_path = Glib::get_home_dir();
+	std::string jackdrc_path = Glib::get_home_dir();
 	jackdrc_path += "/.jackdrc";
 
 	ofstream jackdrc (jackdrc_path.c_str());
@@ -913,7 +928,7 @@ EngineControl::redisplay_latency ()
 void
 EngineControl::audio_mode_changed ()
 {
-	Glib::ustring str = audio_mode_combo.get_active_text();
+	std::string str = audio_mode_combo.get_active_text();
 
 	if (str == _("Playback/Recording on 1 Device")) {
 		input_device_combo.set_sensitive (false);
@@ -1049,7 +1064,7 @@ EngineControl::get_state ()
 {
 	XMLNode* root = new XMLNode ("AudioSetup");
 	XMLNode* child;
-	Glib::ustring path;
+	std::string path;
 
 	child = new XMLNode ("periods");
 	child->add_property ("val", to_string (periods_adjustment.get_value(), std::dec));
