@@ -17,6 +17,7 @@
 
 */
 
+#include <vector>
 #include <ardour/ardour.h>
 
 #include "ardour_ui.h"
@@ -35,11 +36,14 @@
 #include "keyboard.h"
 #include "gui_thread.h"
 #include "opts.h"
+#include "actions.h"
 
 #include "i18n.h"
 
 using namespace PBD;
 using namespace ARDOUR;
+using namespace Gtk;
+using namespace std;
 
 #define KBD_DEBUG 0
 bool debug_keyboard = false;
@@ -57,6 +61,7 @@ guint Keyboard::TertiaryModifier = GDK_SHIFT_MASK; // Shift
 guint Keyboard::Level4Modifier = GDK_CONTROL_MASK; // Control
 guint Keyboard::CopyModifier = GDK_MOD1_MASK;      // Alt/Option
 guint Keyboard::RangeSelectModifier = GDK_SHIFT_MASK;   
+guint Keyboard::button2_modifiers = Keyboard::SecondaryModifier|Keyboard::Level4Modifier;
 #else
 guint Keyboard::PrimaryModifier = GDK_CONTROL_MASK; // Control
 guint Keyboard::SecondaryModifier = GDK_MOD1_MASK;  // Alt/Option
@@ -64,6 +69,7 @@ guint Keyboard::TertiaryModifier = GDK_SHIFT_MASK;  // Shift
 guint Keyboard::Level4Modifier = GDK_MOD4_MASK;     // Mod4/Windows
 guint Keyboard::CopyModifier = GDK_CONTROL_MASK;    
 guint Keyboard::RangeSelectModifier = GDK_SHIFT_MASK;   
+guint Keyboard::button2_modifiers = 0; /* not used */
 #endif
 
 Keyboard*    Keyboard::_the_keyboard = 0;
@@ -72,8 +78,10 @@ bool         Keyboard::_some_magic_widget_has_focus = false;
 
 std::string Keyboard::user_keybindings_path;
 bool Keyboard::can_save_keybindings = false;
+bool Keyboard::bindings_changed_after_save_became_legal = false;
 map<string,string> Keyboard::binding_files;
-std::string Keyboard::_current_binding_name = _("Unknown");
+string Keyboard::_current_binding_name;
+map<AccelKey,pair<string,string>,Keyboard::AccelKeyLess> Keyboard::release_keys;
 
 /* set this to initially contain the modifiers we care about, then track changes in ::set_edit_modifier() etc. */
 
@@ -101,6 +109,7 @@ Keyboard::Keyboard ()
 {
 	if (_the_keyboard == 0) {
 		_the_keyboard = this;
+		_current_binding_name = _("Unknown");
 	}
 
 	RelevantModifierKeyMask = (GdkModifierType) gtk_accelerator_get_default_mod_mask ();
@@ -183,6 +192,7 @@ gint
 Keyboard::snooper (GtkWidget *widget, GdkEventKey *event)
 {
 	uint32_t keyval;
+	bool ret = false;
 
 #if 0
 	cerr << "snoop widget " << widget << " key " << event->keyval << " type: " << event->type 
@@ -212,7 +222,23 @@ Keyboard::snooper (GtkWidget *widget, GdkEventKey *event)
 		if (find (state.begin(), state.end(), keyval) == state.end()) {
 			state.push_back (keyval);
 			sort (state.begin(), state.end());
-		} 
+
+		} else {
+
+			/* key is already down. if its also used for release,
+			   prevent auto-repeat events.
+			*/
+
+			for (map<AccelKey,two_strings,AccelKeyLess>::iterator k = release_keys.begin(); k != release_keys.end(); ++k) {
+
+				const AccelKey& ak (k->first);
+				
+				if (keyval == ak.get_key() && (Gdk::ModifierType)((event->state & Keyboard::RelevantModifierKeyMask)| Gdk::RELEASE_MASK) == ak.get_mod()) {
+					ret = true;
+					break;
+				}
+			}
+		}
 
 	} else if (event->type == GDK_KEY_RELEASE) {
 
@@ -223,16 +249,40 @@ Keyboard::snooper (GtkWidget *widget, GdkEventKey *event)
 			sort (state.begin(), state.end());
 		} 
 
-	}
+		for (map<AccelKey,two_strings,AccelKeyLess>::iterator k = release_keys.begin(); k != release_keys.end(); ++k) {
 
-	if (event->type == GDK_KEY_RELEASE && event->keyval == GDK_w && modifier_state_equals (event->state, PrimaryModifier)) {
-		if (current_window) {
-			current_window->hide ();
-			current_window = 0;
+			const AccelKey& ak (k->first);
+			two_strings ts (k->second);
+
+			if (keyval == ak.get_key() && (Gdk::ModifierType)(event->state | Gdk::RELEASE_MASK) == ak.get_mod()) {
+				Glib::RefPtr<Gtk::Action> act = ActionManager::get_action (ts.first.c_str(), ts.second.c_str());
+				if (act) {
+					act->activate();
+					ret = true;
+				}
+				break;
+			}
 		}
 	}
 
-	return false;
+	/* Special keys that we want to handle in
+	   any dialog, no matter whether it uses
+	   the regular set of accelerators or not
+	*/
+
+	if (event->type == GDK_KEY_RELEASE && modifier_state_equals (event->state, PrimaryModifier)) {
+		switch (event->keyval) {
+		case GDK_w:
+			if (current_window) {
+				current_window->hide ();
+				current_window = 0;
+				ret = true;
+			}
+			break;
+		}
+	}
+
+	return ret;
 }
 
 bool
@@ -251,25 +301,29 @@ Keyboard::enter_window (GdkEventCrossing *ev, Gtk::Window* win)
 bool
 Keyboard::leave_window (GdkEventCrossing *ev, Gtk::Window* win)
 {
-	switch (ev->detail) {
-	case GDK_NOTIFY_INFERIOR:
-		if (debug_keyboard) {
-			cerr << "INFERIOR crossing ... out\n";
+	if (ev) {
+		switch (ev->detail) {
+		case GDK_NOTIFY_INFERIOR:
+			if (debug_keyboard) {
+				cerr << "INFERIOR crossing ... out\n";
+			}
+			break;
+			
+		case GDK_NOTIFY_VIRTUAL:
+			if (debug_keyboard) {
+				cerr << "VIRTUAL crossing ... out\n";
+			}
+			/* fallthru */
+			
+		default:
+			if (debug_keyboard) {
+				cerr << "REAL CROSSING ... out\n";
+				cerr << "clearing current target\n";
+			}
+			state.clear ();
+			current_window = 0;
 		}
-		break;
-
-	case GDK_NOTIFY_VIRTUAL:
-		if (debug_keyboard) {
-			cerr << "VIRTUAL crossing ... out\n";
-		}
-		/* fallthru */
-
-	default:
-		if (debug_keyboard) {
-			cerr << "REAL CROSSING ... out\n";
-			cerr << "clearing current target\n";
-		}
-		state.clear ();
+	} else {
 		current_window = 0;
 	}
 
@@ -323,12 +377,23 @@ Keyboard::set_snap_modifier (guint mod)
 bool
 Keyboard::is_edit_event (GdkEventButton *ev)
 {
-
 	return (ev->type == GDK_BUTTON_PRESS || ev->type == GDK_BUTTON_RELEASE) && 
 		(ev->button == Keyboard::edit_button()) && 
 		((ev->state & RelevantModifierKeyMask) == Keyboard::edit_modifier());
 }
 
+bool
+Keyboard::is_button2_event (GdkEventButton* ev)
+{
+#ifdef GTKOSX
+	return (ev->button == 2) || 
+		((ev->button == 1) && 
+		 ((ev->state & Keyboard::button2_modifiers) == Keyboard::button2_modifiers));
+#else
+	return ev->button == 2;
+#endif	
+}
+
 bool
 Keyboard::is_delete_event (GdkEventButton *ev)
 {
@@ -385,6 +450,16 @@ accel_map_changed (GtkAccelMap* map,
 		   GdkModifierType mod,
 		   gpointer arg)
 {
+	Keyboard::keybindings_changed ();
+}
+
+void
+Keyboard::keybindings_changed ()
+{
+	if (Keyboard::can_save_keybindings) {
+		Keyboard::bindings_changed_after_save_became_legal = true;
+	}
+
 	Keyboard::save_keybindings ();
 }
 
@@ -397,7 +472,7 @@ Keyboard::set_can_save_keybindings (bool yn)
 void
 Keyboard::save_keybindings ()
 {
-	if (can_save_keybindings) {
+	if (can_save_keybindings && bindings_changed_after_save_became_legal) {
 		Gtk::AccelMap::save (user_keybindings_path);
 	} 
 }
@@ -488,7 +563,7 @@ Keyboard::setup_keybindings ()
 			if (path.empty()) {
 				
 				if (keybindings_path == default_bindings) {
-					error << _("Default keybindings not found - Ardour will be hard to use!") << endmsg;
+					error << string_compose (_("Default keybindings not found - %1 will be hard to use!"), PROGRAM_NAME) << endmsg;
 					return;
 				} else {
 					warning << string_compose (_("Key bindings file \"%1\" not found. Default bindings used instead"), 
@@ -512,7 +587,7 @@ Keyboard::setup_keybindings ()
 
 			if (!Glib::file_test (keybindings_path, Glib::FILE_TEST_EXISTS)) {
 				if (keybindings_path == default_bindings) {
-					error << _("Default keybindings not found - Ardour will be hard to use!") << endmsg;
+					error << string_compose (_("Default keybindings not found - %1 will be hard to use!"), PROGRAM_NAME) << endmsg;
 					return;
 				} else {
 					warning << string_compose (_("Key bindings file \"%1\" not found. Default bindings used instead"), 
@@ -552,13 +627,50 @@ Keyboard::load_keybindings (string path)
 			}
 		}
 
-		return true;
 
 	} catch (...) {
-		error << string_compose (_("Ardour key bindings file not found at \"%1\" or contains errors."), path)
+		error << string_compose (_("%1 key bindings file not found at \"%2\" or contains errors."), PROGRAM_NAME, path)
 		      << endmsg;
 		return false;
 	}
+
+	/* now find all release-driven bindings */
+
+	vector<string> groups;
+	vector<string> names;
+	vector<AccelKey> bindings;
+	
+	ActionManager::get_all_actions (groups, names, bindings);
+	
+	vector<string>::iterator g;
+	vector<AccelKey>::iterator b;
+	vector<string>::iterator n;
+
+	release_keys.clear ();
+
+	bool show_bindings = (getenv ("ARDOUR_SHOW_BINDINGS") != 0);
+
+	for (n = names.begin(), b = bindings.begin(), g = groups.begin(); n != names.end(); ++n, ++b, ++g) {
+
+		if (show_bindings) {
+			
+			cerr << "Action: " << (*n) << " Group: " << (*g) << " binding = ";
+			
+			if ((*b).get_key() != GDK_VoidSymbol) {
+				cerr << (*b).get_key() << " w/mod = " << hex << (*b).get_mod() << dec << " = " << (*b).get_abbrev();
+			} else {
+				cerr << "unbound";
+			}
+			
+			cerr << endl;
+		}
+
+		if ((*b).get_mod() & Gdk::RELEASE_MASK) {
+			release_keys.insert (pair<AccelKey,two_strings> (*b, two_strings (*g, *n)));
+		}
+	}
+
+	return true;
 }
 
 
