@@ -52,7 +52,7 @@ using namespace PBD;
 sigc::signal<void>  DPIReset;
 
 int
-pixel_width (const ustring& str, Pango::FontDescription& font)
+pixel_width (const string& str, Pango::FontDescription& font)
 {
 	if (str.empty()) {
 		return 0;
@@ -69,20 +69,20 @@ pixel_width (const ustring& str, Pango::FontDescription& font)
 	return width;
 }
 
-ustring
-fit_to_pixels (const ustring& str, int pixel_width, Pango::FontDescription& font, int& actual_width, bool with_ellipses)
+string
+fit_to_pixels (const string& str, int pixel_width, Pango::FontDescription& font, int& actual_width, bool with_ellipses)
 {
 	Label foo;
 	Glib::RefPtr<Pango::Layout> layout = foo.create_pango_layout ("");
-	ustring::size_type shorter_by = 0;
-	ustring txt;
+	string::size_type shorter_by = 0;
+	string txt;
 
 	layout->set_font_description (font);
 
 	actual_width = 0;
 
-	ustring ustr = str;
-	ustring::iterator last = ustr.end();
+	string ustr = str;
+	string::iterator last = ustr.end();
 	--last; /* now points at final entry */
 
 	txt = ustr;
@@ -485,7 +485,7 @@ key_press_focus_accelerator_handler (Gtk::Window& window, GdkEventKey* ev)
 	bool special_handling_of_unmodified_accelerators = false;
 	bool allow_activating = true;
 
-//#define DEBUG_ACCELERATOR_HANDLING
+// #define DEBUG_ACCELERATOR_HANDLING
 #ifdef  DEBUG_ACCELERATOR_HANDLING
 	//bool debug = (getenv ("ARDOUR_DEBUG_ACCELERATOR_HANDLING") != 0);
 	bool debug=true;
@@ -510,7 +510,8 @@ key_press_focus_accelerator_handler (Gtk::Window& window, GdkEventKey* ev)
 	if (debug) {
 		cerr << "Win = " << win << " Key event: code = " << ev->keyval << " name = " << gdk_keyval_name (ev->keyval) << " state = " << hex << ev->state << dec 
 		     << " ctrl " << ((ev->state & GDK_CONTROL_MASK) ? 1 : 0)
-		     << " alt " << ((ev->state & GDK_MOD1_MASK) ? 1 : 0)
+		     << " alt/mod1 " << ((ev->state & GDK_MOD1_MASK) ? 1 : 0)
+		     << " mod2 " << ((ev->state & GDK_MOD2_MASK) ? 1 : 0)
 		     << " shift " << ((ev->state & GDK_SHIFT_MASK) ? 1 : 0)
 		     << " cmd/meta " << ((ev->state & GDK_META_MASK) ? 1 : 0)
 		     << " lock " << ((ev->state & GDK_LOCK_MASK) ? 1 : 0)
@@ -568,7 +569,9 @@ key_press_focus_accelerator_handler (Gtk::Window& window, GdkEventKey* ev)
 #ifdef DEBUG_ACCELERATOR_HANDLING
 				cerr << "Remapped " << gdk_keyval_name (ev->keyval) << " to " << gdk_keyval_name (keyval_without_alt) << endl;
 
-#endif				ev->keyval = keyval_without_alt;
+#endif
+				ev->keyval = keyval_without_alt;
+				ev->group = 0;
 			}
 		}
 	}
@@ -861,6 +864,7 @@ convert_color_channel (guint8 src,
 	return alpha ? ((guint (src) << 8) - src) / alpha : 0;
 }
 
+
 void
 convert_bgra_to_rgba (guint8 const* src,
 		      guint8*       dst,
@@ -870,24 +874,46 @@ convert_bgra_to_rgba (guint8 const* src,
 	guint8 const* src_pixel = src;
 	guint8*       dst_pixel = dst;
 	
-	for (int y = 0; y < height; y++)
-		for (int x = 0; x < width; x++)
-		{
-			dst_pixel[0] = convert_color_channel (src_pixel[2],
-							      src_pixel[3]);
-			dst_pixel[1] = convert_color_channel (src_pixel[1],
-							      src_pixel[3]);
-			dst_pixel[2] = convert_color_channel (src_pixel[0],
-							      src_pixel[3]);
-			dst_pixel[3] = src_pixel[3];
-			
-			dst_pixel += 4;
-			src_pixel += 4;
-		}
+	for (int y = 0; y < height; y++) {
+	  for (int x = 0; x < width; x++) {
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
+	    /* Cairo [ B G R A ] is actually  [ B G R A ] in memory SOURCE
+	                                        0 1 2 3
+	       Pixbuf [ R G B A ] is actually [ R G B A ] in memory DEST
+	    */
+	    dst_pixel[0] = convert_color_channel (src_pixel[2],
+						  src_pixel[3]); // R [0] <= [ 2 ]
+	    dst_pixel[1] = convert_color_channel (src_pixel[1],
+						  src_pixel[3]); // G [1] <= [ 1 ]
+	    dst_pixel[2] = convert_color_channel (src_pixel[0],  
+						  src_pixel[3]); // B [2] <= [ 0 ]
+	    dst_pixel[3] = src_pixel[3]; // alpha
+	    
+#elif G_BYTE_ORDER == G_BIG_ENDIAN
+	    /* Cairo [ B G R A ] is actually  [ A R G B ] in memory SOURCE
+	                                        0 1 2 3
+	       Pixbuf [ R G B A ] is actually [ R G B A ] in memory DEST
+	    */
+	    dst_pixel[0] = convert_color_channel (src_pixel[1],
+						  src_pixel[0]); // R [0] <= [ 1 ]
+	    dst_pixel[1] = convert_color_channel (src_pixel[2],
+						  src_pixel[0]); // G [1] <= [ 2 ]
+	    dst_pixel[2] = convert_color_channel (src_pixel[3],
+						  src_pixel[0]); // B [2] <= [ 3 ]
+	    dst_pixel[3] = src_pixel[0]; // alpha
+	    
+#else
+#error ardour does not currently support PDP-endianess
+#endif			
+
+	    dst_pixel += 4;
+	    src_pixel += 4;
+	  }
+	}
 }
 
 Glib::RefPtr<Gdk::Pixbuf>
-pixbuf_from_ustring(const ustring& name, Pango::FontDescription* font, uint32_t rgba, int clip_width, int clip_height)
+pixbuf_from_string(const string& name, Pango::FontDescription* font, uint32_t rgba, int clip_width, int clip_height)
 {
 	Glib::RefPtr<Gdk::Pixbuf> buf = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, clip_width, clip_height);
 	cairo_surface_t* surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, clip_width, clip_height);
@@ -917,3 +943,33 @@ pixbuf_from_ustring(const ustring& name, Pango::FontDescription* font, uint32_t
 
 	return buf;
 }
+
+int
+physical_screen_height (Glib::RefPtr<Gdk::Window> win)
+{
+        GdkScreen* scr = gdk_screen_get_default();
+
+        if (win) {
+                GdkRectangle r;
+                gint monitor = gdk_screen_get_monitor_at_window (scr, win->gobj());
+                gdk_screen_get_monitor_geometry (scr, monitor, &r);
+                return r.height;
+        } else {
+                return gdk_screen_get_height (scr);
+        }
+}
+
+int
+physical_screen_width (Glib::RefPtr<Gdk::Window> win)
+{
+        GdkScreen* scr = gdk_screen_get_default();
+        
+        if (win) {
+                GdkRectangle r;
+                gint monitor = gdk_screen_get_monitor_at_window (scr, win->gobj());
+                gdk_screen_get_monitor_geometry (scr, monitor, &r);
+                return r.width;
+        } else {
+                return gdk_screen_get_width (scr);
+        }
+}
