@@ -267,7 +267,7 @@ class Session : public PBD::StatefulDestructible
 	
 	int ensure_subdirs ();
 
-	Glib::ustring peak_path (Glib::ustring) const;
+	std::string peak_path (std::string) const;
 
 	static string suffixed_search_path (std::string suffix, bool data);
 	static string control_protocol_path ();
@@ -444,6 +444,7 @@ class Session : public PBD::StatefulDestructible
 	nframes_t worst_output_latency () const { return _worst_output_latency; }
 	nframes_t worst_input_latency () const { return _worst_input_latency; }
 	nframes_t worst_track_latency () const { return _worst_track_latency; }
+	nframes_t worst_playback_latency () const { return _worst_output_latency + _worst_track_latency; }
 
 	int save_state (string snapshot_name, bool pending = false, bool switch_to_snapshot = false);
 	int restore_state (string snapshot_name);
@@ -616,7 +617,7 @@ class Session : public PBD::StatefulDestructible
 	    uint32_t count;
 	    SrcQuality quality;
 	    volatile bool freeze;
-	    std::vector<Glib::ustring> paths;
+	    std::vector<std::string> paths;
 	    bool replace_existing_source;
 	    
 	    /* result */
@@ -680,7 +681,7 @@ class Session : public PBD::StatefulDestructible
 	boost::shared_ptr<AudioFileSource> create_audio_source_for_session (ARDOUR::AudioDiskstream&, uint32_t which_channel, bool destructive);
 
 	boost::shared_ptr<Source> source_by_id (const PBD::ID&);
-	boost::shared_ptr<Source> source_by_path_and_channel (const Glib::ustring&, uint16_t);
+	boost::shared_ptr<Source> source_by_path_and_channel (const std::string&, uint16_t);
 
 	/* playlist management */
 
@@ -1000,7 +1001,7 @@ class Session : public PBD::StatefulDestructible
   protected:
 	friend class Route;
 	void schedule_curve_reallocation ();
-	void update_latency_compensation (bool, bool);
+	void update_latency_compensation (bool force_whole_graph = false);
 	
   private:
 	int  create (bool& new_session, const string& mix_template, nframes_t initial_length);
@@ -1065,10 +1066,15 @@ class Session : public PBD::StatefulDestructible
 	bool                    _end_location_is_free;
 	bool                    _was_seamless;
 
+        void initialize_latencies ();
 	void set_worst_io_latencies ();
-	void set_worst_io_latencies_x (IOChange asifwecare, void *ignored) {
+	void set_worst_playback_latency ();
+	void set_worst_capture_latency ();
+	void set_worst_io_latencies_x (IOChange, void *) {
 		set_worst_io_latencies ();
 	}
+	void post_capture_latency ();
+	void post_playback_latency ();
 
 	void route_redirects_changed (void* ignored);
 
@@ -1686,6 +1692,8 @@ class Session : public PBD::StatefulDestructible
 	void reset_jack_connection (jack_client_t* jack);
 	void record_enable_change_all (bool yn);
 
+	void  update_latency (bool playback);
+
 	XMLNode& state(bool);
 
 	/* click track */
