@@ -47,8 +47,6 @@
 
 #include <CoreFoundation/CoreFoundation.h>
 #include <CoreServices/CoreServices.h>
-#include <AudioUnit/AudioUnit.h>
-#include <AudioToolbox/AudioUnitUtilities.h>
 
 #include "i18n.h"
 
@@ -138,7 +136,7 @@ _get_transport_state_callback (void*     userData,
 
 
 static int 
-save_property_list (CFPropertyListRef propertyList, Glib::ustring path)
+save_property_list (CFPropertyListRef propertyList, std::string path)
 
 {
 	CFDataRef xmlData;
@@ -186,7 +184,7 @@ save_property_list (CFPropertyListRef propertyList, Glib::ustring path)
  
 
 static CFPropertyListRef 
-load_property_list (Glib::ustring path) 
+load_property_list (std::string path) 
 {
 	int fd;
 	CFPropertyListRef propertyList = 0;
@@ -355,11 +353,13 @@ AUPlugin::AUPlugin (AudioEngine& engine, Session& session, boost::shared_ptr<CAC
 	, current_offset (0)
 	, current_buffers (0)
 	, frames_processed (0)
+	, _parameter_listener (0)
+	, _parameter_listener_arg (0)
 	, last_transport_rolling (false)
 	, last_transport_speed (0.0)
 {			
 	if (!preset_search_path_initialized) {
-		Glib::ustring p = Glib::get_home_dir();
+		std::string p = Glib::get_home_dir();
 		p += "/Library/Audio/Presets:";
 		p += preset_search_path;
 		preset_search_path = p;
@@ -382,13 +382,21 @@ AUPlugin::AUPlugin (const AUPlugin& other)
 	, current_offset (0)
 	, current_buffers (0)
 	, frames_processed (0)
-	  
+	, _parameter_listener (0)
+	, _parameter_listener_arg (0)
+	, last_transport_rolling (false)
+	, last_transport_speed (0.0)
 {
 	init ();
 }
 
 AUPlugin::~AUPlugin ()
 {
+	if (_parameter_listener) {
+		AUListenerDispose (_parameter_listener);
+		_parameter_listener = 0;
+	}
+	
 	if (unit) {
 		TRACE_API ("about to call uninitialize in plugin destructor\n");
 		unit->Uninitialize ();
@@ -446,17 +454,26 @@ AUPlugin::init ()
 		throw failed_constructor ();
 	}
 	
-	AURenderCallbackStruct renderCallbackInfo;
+	TRACE_API ("count global elements\n");
+	unit->GetElementCount (kAudioUnitScope_Global, global_elements);
+	TRACE_API ("count input elements\n");
+	unit->GetElementCount (kAudioUnitScope_Input, input_elements);
+	TRACE_API ("count output elements\n");
+	unit->GetElementCount (kAudioUnitScope_Output, output_elements);
 
-	renderCallbackInfo.inputProc = _render_callback;
-	renderCallbackInfo.inputProcRefCon = this;
-
-	TRACE_API ("set render callback in input scope\n");
-	if ((err = unit->SetProperty (kAudioUnitProperty_SetRenderCallback, kAudioUnitScope_Input, 
-					 0, (void*) &renderCallbackInfo, sizeof(renderCallbackInfo))) != 0) {
-		cerr << "cannot install render callback (err = " << err << ')' << endl;
-		throw failed_constructor();
-	}
+        if (input_elements > 0) {
+                AURenderCallbackStruct renderCallbackInfo;
+                
+                renderCallbackInfo.inputProc = _render_callback;
+                renderCallbackInfo.inputProcRefCon = this;
+                
+                TRACE_API ("set render callback in input scope\n");
+                if ((err = unit->SetProperty (kAudioUnitProperty_SetRenderCallback, kAudioUnitScope_Input, 
+                                              0, (void*) &renderCallbackInfo, sizeof(renderCallbackInfo))) != 0) {
+                        cerr << "cannot install render callback (err = " << err << ')' << endl;
+                        throw failed_constructor();
+                }
+        }
 
 	/* tell the plugin about tempo/meter/transport callbacks in case it wants them */
 
@@ -475,13 +492,6 @@ AUPlugin::init ()
 			   &info,
 			   sizeof (HostCallbackInfo));
 
-	TRACE_API ("count global elements\n");
-	unit->GetElementCount (kAudioUnitScope_Global, global_elements);
-	TRACE_API ("count input elements\n");
-	unit->GetElementCount (kAudioUnitScope_Input, input_elements);
-	TRACE_API ("count output elements\n");
-	unit->GetElementCount (kAudioUnitScope_Output, output_elements);
-
 	/* these keep track of *configured* channel set up,
 	   not potential set ups.
 	*/
@@ -494,6 +504,7 @@ AUPlugin::init ()
 		throw failed_constructor();
 	}
 
+	create_parameter_listener (AUPlugin::_parameter_change_listener, this, 0.05);
 	discover_parameters ();
 	discover_factory_presets ();
 
@@ -609,11 +620,14 @@ AUPlugin::discover_parameters ()
 			d.max_unbound = 0; // upper is bound
 
 			descriptors.push_back (d);
+
+			uint32_t last_param = descriptors.size() - 1;
+			parameter_map.insert (pair<uint32_t,uint32_t> (d.id, last_param));
+			listen_to_parameter (last_param);
 		}
 	}
 }
 
-
 static unsigned int
 four_ints_to_four_byte_literal (unsigned char n[4])
 {
@@ -757,24 +771,34 @@ AUPlugin::latency () const
 void
 AUPlugin::set_parameter (uint32_t which, float val)
 {
-	if (which < descriptors.size()) {
-		const AUParameterDescriptor& d (descriptors[which]);
-		TRACE_API ("set parameter %d in scope %d element %d to %f\n", d.id, d.scope, d.element, val);
-		unit->SetParameter (d.id, d.scope, d.element, val);
-
-		/* tell the world what we did */
-
-		AudioUnitEvent theEvent;
-		
-		theEvent.mEventType = kAudioUnitEvent_ParameterValueChange;
-		theEvent.mArgument.mParameter.mAudioUnit = unit->AU();
-		theEvent.mArgument.mParameter.mParameterID = d.id;
-		theEvent.mArgument.mParameter.mScope = d.scope;
-		theEvent.mArgument.mParameter.mElement = d.element;
-
-		TRACE_API ("notify about parameter change\n");
-		AUEventListenerNotify (NULL, NULL, &theEvent);
+	if (which >= descriptors.size()) {
+		return;
 	}
+
+	const AUParameterDescriptor& d (descriptors[which]);
+	TRACE_API ("set parameter %d in scope %d element %d to %f\n", d.id, d.scope, d.element, val);
+	unit->SetParameter (d.id, d.scope, d.element, val);
+	
+	/* tell the world what we did */
+	
+	AudioUnitEvent theEvent;
+	
+	theEvent.mEventType = kAudioUnitEvent_ParameterValueChange;
+	theEvent.mArgument.mParameter.mAudioUnit = unit->AU();
+	theEvent.mArgument.mParameter.mParameterID = d.id;
+	theEvent.mArgument.mParameter.mScope = d.scope;
+	theEvent.mArgument.mParameter.mElement = d.element;
+	
+	TRACE_API ("notify about parameter change\n");
+
+	/* use the AU Event API to notify about the change. Our own listener will 
+	   end up "emitting" ParameterChanged, and this way ParameterChanged is 
+	   used whether the change to the parameter comes from this function
+	   or within the plugin or anywhere else, since they should all notify
+	   via AUEventListenerNotify().
+	*/
+
+	AUEventListenerNotify (NULL, NULL, &theEvent);
 }
 
 float
@@ -1619,7 +1643,7 @@ AUPlugin::load_preset (const string preset_label)
 #ifdef AU_STATE_SUPPORT
 	bool ret = false;
 	CFPropertyListRef propertyList;
-	Glib::ustring path;
+	std::string path;
 	UserPresetMap::iterator ux;
 	FactoryPresetMap::iterator fx;
 
@@ -1680,8 +1704,8 @@ AUPlugin::save_preset (string preset_name)
 {
 #ifdef AU_STATE_SUPPORT
 	CFPropertyListRef propertyList;
-	vector<Glib::ustring> v;
-	Glib::ustring user_preset_path;
+	vector<std::string> v;
+	std::string user_preset_path;
 	bool ret = true;
 
 	std::string m = maker();
@@ -2017,7 +2041,7 @@ AUPluginInfo::load (Session& session)
 	}
 }
 
-Glib::ustring
+std::string
 AUPluginInfo::au_cache_path ()
 {
 	return Glib::build_filename (ARDOUR::get_user_ardour_path(), "au_cache");
@@ -2280,7 +2304,7 @@ AUPluginInfo::save_cached_info ()
 
 	}
 
-	Glib::ustring path = au_cache_path ();
+	std::string path = au_cache_path ();
 	XMLTree tree;
 
 	tree.set_root (node);
@@ -2294,7 +2318,7 @@ AUPluginInfo::save_cached_info ()
 int
 AUPluginInfo::load_cached_info ()
 {
-	Glib::ustring path = au_cache_path ();
+	std::string path = au_cache_path ();
 	XMLTree tree;
 	
 	if (!Glib::file_test (path, Glib::FILE_TEST_EXISTS)) {
@@ -2392,7 +2416,7 @@ AUPluginInfo::load_cached_info ()
 }
 
 void
-AUPluginInfo::get_names (CAComponentDescription& comp_desc, std::string& name, Glib::ustring& maker)
+AUPluginInfo::get_names (CAComponentDescription& comp_desc, std::string& name, std::string& maker)
 {
 	CFStringRef itemName = NULL;
 
@@ -2464,3 +2488,77 @@ AUPluginInfo::stringify_descriptor (const CAComponentDescription& desc)
 	return s.str();
 }
 
+int
+AUPlugin::create_parameter_listener (AUEventListenerProc cb, void* arg, float interval_secs)
+{
+	CFRunLoopRef run_loop = (CFRunLoopRef) GetCFRunLoopFromEventLoop(GetCurrentEventLoop()); 
+	CFStringRef  loop_mode = kCFRunLoopDefaultMode;
+
+	if (AUEventListenerCreate (cb, arg, run_loop, loop_mode, interval_secs, interval_secs, &_parameter_listener) != noErr) {
+		return -1;
+	}
+
+	_parameter_listener_arg = arg;
+
+	return 0;
+}
+
+int
+AUPlugin::listen_to_parameter (uint32_t param_id)
+{
+	AudioUnitEvent      event;
+
+	if (!_parameter_listener || param_id >= descriptors.size()) {
+		return -2;
+	}
+
+	event.mEventType = kAudioUnitEvent_ParameterValueChange;
+	event.mArgument.mParameter.mAudioUnit = unit->AU();
+	event.mArgument.mParameter.mParameterID = descriptors[param_id].id;
+	event.mArgument.mParameter.mScope = descriptors[param_id].scope;
+	event.mArgument.mParameter.mElement = descriptors[param_id].element;
+
+	if (AUEventListenerAddEventType (_parameter_listener, _parameter_listener_arg, &event) != noErr) {
+		return -1;
+	} 
+
+	return 0;
+}
+
+int
+AUPlugin::end_listen_to_parameter (uint32_t param_id)
+{
+	AudioUnitEvent      event;
+
+	if (!_parameter_listener || param_id >= descriptors.size()) {
+		return -2;
+	}
+
+	event.mEventType = kAudioUnitEvent_ParameterValueChange;
+	event.mArgument.mParameter.mAudioUnit = unit->AU();
+	event.mArgument.mParameter.mParameterID = descriptors[param_id].id;
+	event.mArgument.mParameter.mScope = descriptors[param_id].scope;
+	event.mArgument.mParameter.mElement = descriptors[param_id].element;
+
+	if (AUEventListenerRemoveEventType (_parameter_listener, _parameter_listener_arg, &event) != noErr) {
+		return -1;
+	} 
+
+	return 0;
+}
+
+void
+AUPlugin::_parameter_change_listener (void* arg, void* src, const AudioUnitEvent* event, UInt64 host_time, Float32 new_value)
+{
+	((AUPlugin*) arg)->parameter_change_listener (arg, src, event, host_time, new_value);
+}
+
+void
+AUPlugin::parameter_change_listener (void* /*arg*/, void* /*src*/, const AudioUnitEvent* event, UInt64 host_time, Float32 new_value)
+{
+	ParameterMap::iterator i = parameter_map.find (event->mArgument.mParameter.mParameterID);
+
+	if (i != parameter_map.end()) {
+		ParameterChanged (i->second, new_value);
+	}
+}
