@@ -260,7 +260,7 @@ IO::apply_declick (vector<Sample *>& bufs, uint32_t nbufs, nframes_t nframes, ga
 
 	if (nframes == 0) return;
 	
-	fractional_shift = -1.0/declick;
+	fractional_shift = -1.0/(declick-1);
 
 	if (target < initial) {
 		/* fade out: remove more and more of delta from initial */
@@ -1063,13 +1063,14 @@ IO::disconnect_outputs (void* src)
 	return 0;
 }
 
-bool
-IO::ensure_inputs_locked (uint32_t n, bool clear, void* src)
+int
+IO::ensure_inputs_locked (uint32_t n, bool clear, void* src, bool& changed)
 {
 	Port* input_port;
-	bool changed = false;
 	bool reduced = false;
 	
+        changed = false;
+	
 	/* remove unused ports */
 
 	while (_ninputs > n) {
@@ -1125,7 +1126,7 @@ IO::ensure_inputs_locked (uint32_t n, bool clear, void* src)
 		}
 	}
 
-	return changed;
+	return 0;
 }
 
 int
@@ -1286,9 +1287,13 @@ IO::ensure_inputs (uint32_t n, bool clear, bool lockit, void* src)
 	if (lockit) {
 		BLOCK_PROCESS_CALLBACK ();
 		Glib::Mutex::Lock im (io_lock);
-		changed = ensure_inputs_locked (n, clear, src);
+		if (ensure_inputs_locked (n, clear, src, changed)) {
+                        return -1;
+                }
 	} else {
-		changed = ensure_inputs_locked (n, clear, src);
+		if (ensure_inputs_locked (n, clear, src, changed)) {
+                        return -1;
+                }
 	}
 
 	if (changed) {
@@ -1299,14 +1304,15 @@ IO::ensure_inputs (uint32_t n, bool clear, bool lockit, void* src)
 	return 0;
 }
 
-bool
-IO::ensure_outputs_locked (uint32_t n, bool clear, void* src)
+int
+IO::ensure_outputs_locked (uint32_t n, bool clear, void* src, bool& changed)
 {
 	Port* output_port;
-	bool changed = false;
 	bool reduced = false;
 	bool need_pan_reset;
 
+	changed = false;
+
 	if (_noutputs == n) {
 		need_pan_reset = false;
 	} else {
@@ -1362,7 +1368,7 @@ IO::ensure_outputs_locked (uint32_t n, bool clear, void* src)
 		}
 	}
 
-	return changed;
+	return 0;
 }
 
 int
@@ -1382,9 +1388,13 @@ IO::ensure_outputs (uint32_t n, bool clear, bool lockit, void* src)
 	if (lockit) {
 		BLOCK_PROCESS_CALLBACK ();
 		Glib::Mutex::Lock im (io_lock);
-		changed = ensure_outputs_locked (n, clear, src);
+                if (ensure_outputs_locked (n, clear, src, changed)) {
+                        return -1;
+                }
 	} else {
-		changed = ensure_outputs_locked (n, clear, src);
+		if (ensure_outputs_locked (n, clear, src, changed)) {
+                        return -1;
+                }
 	}
 
 	if (changed) {
@@ -2200,16 +2210,6 @@ IO::set_output_maximum (int n)
 	_output_maximum = n;
 }
 
-void
-IO::set_port_latency (nframes_t nframes)
-{
-	Glib::Mutex::Lock lm (io_lock);
-
-	for (vector<Port *>::iterator i = _outputs.begin(); i != _outputs.end(); ++i) {
-		(*i)->set_latency (nframes);
-	}
-}
-
 nframes_t
 IO::output_latency () const
 {
@@ -2221,7 +2221,7 @@ IO::output_latency () const
 	/* io lock not taken - must be protected by other means */
 
 	for (vector<Port *>::const_iterator i = _outputs.begin(); i != _outputs.end(); ++i) {
-		if ((latency = _session.engine().get_port_total_latency (*(*i))) > max_latency) {
+		if ((latency = (*i)->private_latency_range (true).max) > max_latency) {
 			max_latency = latency;
 		}
 	}
@@ -2240,7 +2240,7 @@ IO::input_latency () const
 	/* io lock not taken - must be protected by other means */
 
 	for (vector<Port *>::const_iterator i = _inputs.begin(); i != _inputs.end(); ++i) {
-		if ((latency = _session.engine().get_port_total_latency (*(*i))) > max_latency) {
+		if ((latency = (*i)->private_latency_range (false).max) > max_latency) {
 			max_latency = latency;
 		}
 	}
@@ -2683,7 +2683,7 @@ IO::end_gain_touch ()
                 when = _session.transport_frame();
         }
 
-	_gain_automation_curve.stop_touch (mark, when);
+	_gain_automation_curve.stop_touch (mark, when, gain());
 }
 
 void
@@ -2706,7 +2706,7 @@ IO::end_pan_touch (uint32_t which)
                         when = _session.transport_frame();
                 }
                 
-		(*_panner)[which]->automation().stop_touch(mark, when);
+		(*_panner)[which]->automation().stop_touch(mark, when, 0);
 	}
 }
 
