@@ -1,4 +1,5 @@
 #include <unistd.h>
+#include <cstdlib>
 
 #include <pbd/abstract_ui.h>
 #include <pbd/pthread_utils.h>
@@ -8,11 +9,22 @@
 
 using namespace std;
 
+template<typename RequestBuffer> void 
+cleanup_request_buffer (void* ptr)
+{
+        RequestBuffer* rb = (RequestBuffer*) ptr;
+
+        {
+                Glib::Mutex::Lock lm (rb->ui.request_buffer_map_lock);
+                rb->dead = true;
+        }
+}
+
 template <typename RequestObject>
 AbstractUI<RequestObject>::AbstractUI (string name, bool with_signal_pipes)
 	: BaseUI (name, with_signal_pipes)
 {
-	if (pthread_key_create (&thread_request_buffer_key, 0)) {
+	if (pthread_key_create (&thread_request_buffer_key, cleanup_request_buffer<RequestBuffer>)) {
 		cerr << _("cannot create thread request buffer key") << endl;
 		throw failed_constructor();
 	}
@@ -30,10 +42,24 @@ AbstractUI<RequestObject>::register_thread (pthread_t thread_id, string name)
 template <typename RequestObject> void
 AbstractUI<RequestObject>::register_thread_with_request_count (pthread_t thread_id, string thread_name, uint32_t num_requests)
 {
-	RequestBuffer* b = new RequestBuffer (num_requests);
+	RequestBuffer* rbuf = static_cast<RequestBuffer*>(pthread_getspecific (thread_request_buffer_key));
 
+        /* we require that the thread being registered is the caller */
+
+        if (thread_id != pthread_self()) {
+                cerr << "thread attempts to register some other thread with the UI named " << name() << endl;
+                abort ();
+        }
+
+        if (rbuf) {
+                /* this thread is already registered with this AbstractUI */
+                return;
+        }
+
+	RequestBuffer* b = new RequestBuffer (num_requests, *this);
+        
 	{
-        Glib::Mutex::Lock lm (request_buffer_map_lock);
+                Glib::Mutex::Lock lm (request_buffer_map_lock);
 		request_buffers[thread_id] = b;
 	}
 
@@ -93,33 +119,42 @@ AbstractUI<RequestObject>::handle_ui_requests ()
 
 	request_buffer_map_lock.lock ();
 
-	for (i = request_buffers.begin(); i != request_buffers.end(); ++i) {
+	for (i = request_buffers.begin(); i != request_buffers.end(); ) {
 
 		RequestBufferVector vec;
 
-		while (true) {
-
-			/* we must process requests 1 by 1 because
-			   the request may run a recursive main
-			   event loop that will itself call
-			   handle_ui_requests. when we return
-			   from the request handler, we cannot
-			   expect that the state of queued requests
-			   is even remotely consistent with
-			   the condition before we called it.
-			*/
-
-			i->second->get_read_vector (&vec);
-
-			if (vec.len[0] == 0) {
-				break;
-			} else {
-				request_buffer_map_lock.unlock ();
-				do_request (vec.buf[0]);
-				request_buffer_map_lock.lock ();
-				i->second->increment_read_ptr (1);
-			} 
-		}
+                if ((*i).second->dead) {
+                        delete (*i).second;
+                        RequestBufferMapIterator tmp = i;
+                        ++tmp;
+                        request_buffers.erase (i);
+                        i = tmp;
+                } else {
+                        while (true) {
+                                
+                                /* we must process requests 1 by 1 because
+                                   the request may run a recursive main
+                                   event loop that will itself call
+                                   handle_ui_requests. when we return
+                                   from the request handler, we cannot
+                                   expect that the state of queued requests
+                                   is even remotely consistent with
+                                   the condition before we called it.
+                                */
+                                
+                                i->second->get_read_vector (&vec);
+                                
+                                if (vec.len[0] == 0) {
+                                        break;
+                                } else {
+                                        request_buffer_map_lock.unlock ();
+                                        do_request (vec.buf[0]);
+                                        request_buffer_map_lock.lock ();
+                                        i->second->increment_read_ptr (1);
+                                } 
+                        }
+                        ++i;
+                }
 	}
 
 	request_buffer_map_lock.unlock ();
