@@ -10,10 +10,10 @@
 ///
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Last changed  : $Date: 2007-03-16 17:44:10 -0400 (Fri, 16 Mar 2007) $
-// File revision : $Revision: 1605 $
+// Last changed  : $Date: 2008-07-10 14:37:26 -0400 (Thu, 10 Jul 2008) $
+// File revision : $Revision: 3584 $
 //
-// $Id: RateTransposer.cpp 1605 2007-03-16 21:44:10Z paul $
+// $Id: RateTransposer.cpp 3584 2008-07-10 18:37:26Z nostar $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -39,10 +39,10 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <memory.h>
-#include <assert.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <limits.h>
+#include <cassert>
+#include <cstdlib>
+#include <cstdio>
+#include <climits>
 #include "RateTransposer.h"
 #include "AAFilter.h"
 
